# Guide d'intégration de l'arbre de décision pour les responsables énergie

Ce guide explique comment intégrer l'arbre de décision interactif pour les responsables énergie dans le site WordPress energieplus-lesite.be.

## Contenu du package

Le package contient les fichiers suivants :
- `zingtree-decision-tree.php` : Fichier principal du plugin WordPress
- `zingtree-decision-tree.css` : Styles CSS pour l'arbre de décision
- `zingtree-decision-tree.js` : Script JavaScript pour la logique de l'arbre de décision
- `tree-data.json` : Données de l'arbre de décision au format JSON
- `zingtree_decision_tree.html` : Version autonome de l'arbre de décision (pour référence)

## Installation du plugin

1. Créez un dossier `zingtree-decision-tree` dans le répertoire `/wp-content/plugins/` de votre installation WordPress.
2. Copiez les fichiers suivants dans ce dossier :
   - `zingtree-decision-tree.php`
   - `zingtree-decision-tree.css`
   - `zingtree-decision-tree.js`
   - `tree-data.json`
3. Créez les sous-dossiers suivants dans le dossier du plugin :
   - `assets/css/` - Copiez-y le fichier `zingtree-decision-tree.css`
   - `assets/js/` - Copiez-y le fichier `zingtree-decision-tree.js`
   - `assets/data/` - Copiez-y le fichier `tree-data.json`
4. Activez le plugin dans l'interface d'administration WordPress (Plugins > Plugins installés).

## Utilisation du shortcode

Une fois le plugin activé, vous pouvez utiliser le shortcode `[zingtree_decision_tree]` pour afficher l'arbre de décision sur n'importe quelle page ou article.

Exemple d'utilisation simple :
```
[zingtree_decision_tree]
```

Vous pouvez également personnaliser le titre :
```
[zingtree_decision_tree title="Outil d'aide à la décision pour les responsables énergie"]
```

## Intégration à la page existante

Pour intégrer l'arbre de décision à la page https://energieplus-lesite.be/diagnostic/diagnostic-outil-pour-les-responsables-energies/, suivez ces étapes :

1. Accédez à l'éditeur de la page dans l'interface d'administration WordPress.
2. Insérez le shortcode `[zingtree_decision_tree]` à l'endroit où vous souhaitez afficher l'arbre de décision.
3. Publiez ou mettez à jour la page.

## Personnalisation

### Modification des styles

Pour modifier les styles de l'arbre de décision, éditez le fichier `assets/css/zingtree-decision-tree.css`. Les variables CSS en début de fichier permettent de modifier facilement les couleurs principales :

```css
:root {
    --primary-color: #E30613;
    --secondary-color: #8DD3C7;
    --text-color: #333333;
    --light-gray: #F5F5F5;
    --border-color: #DDDDDD;
    --white: #FFFFFF;
    --font-family: Arial, Helvetica, sans-serif;
}
```

### Modification des données de l'arbre

Pour modifier la structure de l'arbre de décision, éditez le fichier `assets/data/tree-data.json`. Chaque nœud est défini avec :
- Un identifiant unique
- Un titre (`page_title`)
- Un contenu HTML (`content`)
- Des boutons (`buttons`) qui pointent vers d'autres nœuds

Exemple de nœud :
```json
"1": {
    "type": "Content",
    "page_title": "Bienvenue",
    "content": "<p>Bienvenue dans l'outil d'aide à la décision...</p>",
    "buttons": [
        { "button_text": "Commencer", "button_link": "2" }
    ]
}
```

## Dépannage

### L'arbre de décision ne s'affiche pas

- Vérifiez que le plugin est bien activé.
- Assurez-vous que le shortcode est correctement inséré dans la page.
- Vérifiez la console JavaScript du navigateur pour détecter d'éventuelles erreurs.
- Assurez-vous que les fichiers CSS et JavaScript sont bien chargés (vérifiez dans l'inspecteur réseau du navigateur).

### Les styles ne correspondent pas au site

- Vérifiez que les variables CSS dans `zingtree-decision-tree.css` correspondent aux couleurs du site.
- Assurez-vous qu'il n'y a pas de conflits avec d'autres styles CSS du site.

## Support

Pour toute question ou assistance, veuillez contacter l'équipe de support à l'adresse support@energieplus-lesite.be.
