<?php
/**
 * Plugin Name: Zingtree Decision Tree
 * Description: Intégration d'un arbre de décision interactif pour les responsables énergie
 * Version: 1.0
 * Author: Manus
 */

// Empêcher l'accès direct au fichier
if (!defined('ABSPATH')) {
    exit;
}

/**
 * Enregistre les styles et scripts nécessaires
 */
function zingtree_decision_tree_enqueue_scripts() {
    // Enregistrer les styles
    wp_enqueue_style(
        'zingtree-decision-tree-styles',
        plugin_dir_url(__FILE__) . 'assets/css/zingtree-decision-tree.css',
        array(),
        '1.0.0'
    );

    // Enregistrer les scripts
    wp_enqueue_script(
        'zingtree-decision-tree-script',
        plugin_dir_url(__FILE__) . 'assets/js/zingtree-decision-tree.js',
        array('jquery'),
        '1.0.0',
        true
    );

    // Passer des variables au script
    wp_localize_script(
        'zingtree-decision-tree-script',
        'zingtreeData',
        array(
            'ajaxUrl' => admin_url('admin-ajax.php'),
            'nonce' => wp_create_nonce('zingtree_nonce'),
            'treeDataUrl' => plugin_dir_url(__FILE__) . 'assets/data/tree-data.json'
        )
    );
}
add_action('wp_enqueue_scripts', 'zingtree_decision_tree_enqueue_scripts');

/**
 * Shortcode pour afficher l'arbre de décision
 */
function zingtree_decision_tree_shortcode($atts) {
    // Extraire les attributs
    $atts = shortcode_atts(
        array(
            'title' => 'Outil pour les responsables énergies',
        ),
        $atts,
        'zingtree_decision_tree'
    );

    // Commencer à capturer la sortie
    ob_start();
    ?>
    <div id="zingtree-container" class="zingtree-container">
        <div id="node-header" class="node-header"><?php echo esc_html($atts['title']); ?></div>
        <div id="node-content" class="node-content loading"></div>
        <div id="node-buttons" class="node-buttons"></div>
        <div id="navigation-bar" class="navigation-bar">
            <button id="back-button" class="back-button" disabled>Précédent</button>
            <button id="restart-button" class="restart-button">Recommencer</button>
        </div>
        <div id="progress-indicator" class="progress-indicator">
            <div id="progress-bar" class="progress-bar"></div>
        </div>
    </div>
    <?php
    // Récupérer la sortie capturée
    return ob_get_clean();
}
add_shortcode('zingtree_decision_tree', 'zingtree_decision_tree_shortcode');

/**
 * Fonction d'activation du plugin
 */
function zingtree_decision_tree_activate() {
    // Créer les répertoires nécessaires
    $upload_dir = wp_upload_dir();
    $plugin_upload_dir = $upload_dir['basedir'] . '/zingtree-decision-tree';
    
    if (!file_exists($plugin_upload_dir)) {
        wp_mkdir_p($plugin_upload_dir);
    }
}
register_activation_hook(__FILE__, 'zingtree_decision_tree_activate');

/**
 * Fonction de désactivation du plugin
 */
function zingtree_decision_tree_deactivate() {
    // Nettoyer si nécessaire
}
register_deactivation_hook(__FILE__, 'zingtree_decision_tree_deactivate');
